@@ -1,5 +1,31 @@
 var NAVTREEINDEX112 =
 {
+"structnanovdb_1_1BitArray.html":[15,0,3,2],
+"structnanovdb_1_1BitArray_3_0116_01_4.html":[14,0,5,3],
+"structnanovdb_1_1BitArray_3_0116_01_4.html":[15,0,3,3],
+"structnanovdb_1_1BitArray_3_0116_01_4.html#ae2251e09460138f434f445cab7824c08":[14,0,5,3,0],
+"structnanovdb_1_1BitArray_3_0116_01_4.html#ae2251e09460138f434f445cab7824c08":[15,0,3,3,0],
+"structnanovdb_1_1BitArray_3_0132_01_4.html":[14,0,5,4],
+"structnanovdb_1_1BitArray_3_0132_01_4.html":[15,0,3,4],
+"structnanovdb_1_1BitArray_3_0132_01_4.html#a0251ac0c51aa69a1a5f25044b269eae1":[14,0,5,4,0],
+"structnanovdb_1_1BitArray_3_0132_01_4.html#a0251ac0c51aa69a1a5f25044b269eae1":[15,0,3,4,0],
+"structnanovdb_1_1BitArray_3_0164_01_4.html":[14,0,5,5],
+"structnanovdb_1_1BitArray_3_0164_01_4.html":[15,0,3,5],
+"structnanovdb_1_1BitArray_3_0164_01_4.html#af3e2644dc8b717cc20da528c6de31cb3":[14,0,5,5,0],
+"structnanovdb_1_1BitArray_3_0164_01_4.html#af3e2644dc8b717cc20da528c6de31cb3":[15,0,3,5,0],
+"structnanovdb_1_1BitArray_3_018_01_4.html":[14,0,5,6],
+"structnanovdb_1_1BitArray_3_018_01_4.html":[15,0,3,6],
+"structnanovdb_1_1BitArray_3_018_01_4.html#a51fb244e2361235b2287e9d140c4062d":[14,0,5,6,0],
+"structnanovdb_1_1BitArray_3_018_01_4.html#a51fb244e2361235b2287e9d140c4062d":[15,0,3,6,0],
+"structnanovdb_1_1BufferTraits.html":[14,0,5,8],
+"structnanovdb_1_1BufferTraits.html":[15,0,3,8],
+"structnanovdb_1_1BufferTraits.html#ae2c7013b5a04d0316a3517ca603f3bdd":[14,0,5,8,0],
+"structnanovdb_1_1BufferTraits.html#ae2c7013b5a04d0316a3517ca603f3bdd":[15,0,3,8,0],
+"structnanovdb_1_1BuildToValueMap.html":[14,0,5,9],
+"structnanovdb_1_1BuildToValueMap.html":[15,0,3,9],
+"structnanovdb_1_1BuildToValueMap.html#a19462713b2aab2dae2c87c15f262c1df":[14,0,5,9,0],
+"structnanovdb_1_1BuildToValueMap.html#a19462713b2aab2dae2c87c15f262c1df":[14,0,5,10,0],
+"structnanovdb_1_1BuildToValueMap.html#a19462713b2aab2dae2c87c15f262c1df":[14,0,5,11,0],
 "structnanovdb_1_1BuildToValueMap.html#a19462713b2aab2dae2c87c15f262c1df":[14,0,5,12,0],
 "structnanovdb_1_1BuildToValueMap.html#a19462713b2aab2dae2c87c15f262c1df":[14,0,5,13,0],
 "structnanovdb_1_1BuildToValueMap.html#a19462713b2aab2dae2c87c15f262c1df":[14,0,5,14,0],
@@ -223,31 +249,5 @@ var NAVTREEINDEX112 =
 "structnanovdb_1_1GetNodeInfo.html#a13a5ad181dc54970949fa7d7dc660f5c":[15,0,3,40,6],
 "structnanovdb_1_1GetNodeInfo.html#a4d8f3fd354292dad7945828baea1f1a9":[14,0,5,40,3],
 "structnanovdb_1_1GetNodeInfo.html#a4d8f3fd354292dad7945828baea1f1a9":[15,0,3,40,3],
-"structnanovdb_1_1GetNodeInfo.html#a7242fed7aa7a4619d84062c39a942390":[14,0,5,40,2],
-"structnanovdb_1_1GetNodeInfo.html#a7242fed7aa7a4619d84062c39a942390":[15,0,3,40,2],
-"structnanovdb_1_1GetNodeInfo.html#a724e4bea1325decd3467eff6922e0735":[14,0,5,40,5],
-"structnanovdb_1_1GetNodeInfo.html#a724e4bea1325decd3467eff6922e0735":[15,0,3,40,5],
-"structnanovdb_1_1GetNodeInfo.html#aa8eefabeba3f10996fd48ec0a6f7853e":[14,0,5,40,4],
-"structnanovdb_1_1GetNodeInfo.html#aa8eefabeba3f10996fd48ec0a6f7853e":[15,0,3,40,4],
-"structnanovdb_1_1GetNodeInfo.html#aaadeaa4f587d99d39874c9a9677356d3":[14,0,5,40,1],
-"structnanovdb_1_1GetNodeInfo.html#aaadeaa4f587d99d39874c9a9677356d3":[15,0,3,40,1],
-"structnanovdb_1_1GetNodeInfo.html#adfb04c91081d670b0a06f4d07a19d63c":[14,0,5,40,7],
-"structnanovdb_1_1GetNodeInfo.html#adfb04c91081d670b0a06f4d07a19d63c":[15,0,3,40,7],
-"structnanovdb_1_1GetNodeInfo_1_1NodeInfo.html":[14,0,5,40,0],
-"structnanovdb_1_1GetNodeInfo_1_1NodeInfo.html":[15,0,3,40,0],
-"structnanovdb_1_1GetNodeInfo_1_1NodeInfo.html#a6a330c3b2adf87bfa27e9a9450d8bc40":[14,0,5,40,0,3],
-"structnanovdb_1_1GetNodeInfo_1_1NodeInfo.html#a6a330c3b2adf87bfa27e9a9450d8bc40":[15,0,3,40,0,3],
-"structnanovdb_1_1GetNodeInfo_1_1NodeInfo.html#a6eab5d3d217e4ae11e9249f9d622e0e8":[14,0,5,40,0,0],
-"structnanovdb_1_1GetNodeInfo_1_1NodeInfo.html#a6eab5d3d217e4ae11e9249f9d622e0e8":[15,0,3,40,0,0],
-"structnanovdb_1_1GetNodeInfo_1_1NodeInfo.html#a8a5fa0e7abee9d4258c3278b6a70d1f7":[14,0,5,40,0,4],
-"structnanovdb_1_1GetNodeInfo_1_1NodeInfo.html#a8a5fa0e7abee9d4258c3278b6a70d1f7":[15,0,3,40,0,4],
-"structnanovdb_1_1GetNodeInfo_1_1NodeInfo.html#acbf726b103a16e67d039c5d112b07c16":[14,0,5,40,0,1],
-"structnanovdb_1_1GetNodeInfo_1_1NodeInfo.html#acbf726b103a16e67d039c5d112b07c16":[15,0,3,40,0,1],
-"structnanovdb_1_1GetNodeInfo_1_1NodeInfo.html#ace4506405c0d34f2702d0c1e0f9ccc40":[14,0,5,40,0,5],
-"structnanovdb_1_1GetNodeInfo_1_1NodeInfo.html#ace4506405c0d34f2702d0c1e0f9ccc40":[15,0,3,40,0,5],
-"structnanovdb_1_1GetNodeInfo_1_1NodeInfo.html#aededc1200ada83dfb606e876105b8123":[14,0,5,40,0,2],
-"structnanovdb_1_1GetNodeInfo_1_1NodeInfo.html#aededc1200ada83dfb606e876105b8123":[15,0,3,40,0,2],
-"structnanovdb_1_1GetNodeInfo_1_1NodeInfo.html#af44a0f12d9f5e0194cca9e50d630245d":[14,0,5,40,0,6],
-"structnanovdb_1_1GetNodeInfo_1_1NodeInfo.html#af44a0f12d9f5e0194cca9e50d630245d":[15,0,3,40,0,6],
-"structnanovdb_1_1GetState.html":[14,0,5,41]
+"structnanovdb_1_1GetNodeInfo.html#a7242fed7aa7a4619d84062c39a942390":[14,0,5,40,2]
 };
