@@ -1,5 +1,31 @@
 var NAVTREEINDEX32 =
 {
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#a91ae4da602c9adaf39212edf60e8a1c8":[14,0,6,0,5,134,8],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#a91ae4da602c9adaf39212edf60e8a1c8":[15,0,4,0,4,133,8],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#a9d6c5aec365dacbb6d8eac5f62404129":[14,0,6,0,5,134,9],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#a9d6c5aec365dacbb6d8eac5f62404129":[15,0,4,0,4,133,9],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#aa0799ed67481b065ff57b8c721d51e50":[14,0,6,0,5,134,7],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#aa0799ed67481b065ff57b8c721d51e50":[15,0,4,0,4,133,7],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#ab3b50ad1fecad727b434af678dc38f13":[14,0,6,0,5,134,13],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#ab3b50ad1fecad727b434af678dc38f13":[15,0,4,0,4,133,13],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#ab5388e403c00c365cf358a85af632fe5":[14,0,6,0,5,134,4],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#ab5388e403c00c365cf358a85af632fe5":[15,0,4,0,4,133,4],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#ab7bb49e181c1ccad52de629de038e762":[14,0,6,0,5,134,25],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#ab7bb49e181c1ccad52de629de038e762":[15,0,4,0,4,133,25],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#abe280da7072440c8fb03d73741169995":[14,0,6,0,5,134,0],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#abe280da7072440c8fb03d73741169995":[15,0,4,0,4,133,0],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#ac0190b178fb3437704d12ff613accb7f":[14,0,6,0,5,134,16],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#ac0190b178fb3437704d12ff613accb7f":[15,0,4,0,4,133,16],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#ac0fbc408a27381b7ae4017954f93fdb6":[14,0,6,0,5,134,11],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#ac0fbc408a27381b7ae4017954f93fdb6":[15,0,4,0,4,133,11],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#ac3cb3cc7955f3790f737bac5f6ded6f1":[14,0,6,0,5,134,22],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#ac3cb3cc7955f3790f737bac5f6ded6f1":[15,0,4,0,4,133,22],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#adf40cc698b9d4b42f5b5740492deeaa9":[14,0,6,0,5,134,14],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#adf40cc698b9d4b42f5b5740492deeaa9":[15,0,4,0,4,133,14],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#ae83fe5f85ef3c031cd27e541cfe84341":[14,0,6,0,5,134,3],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#ae83fe5f85ef3c031cd27e541cfe84341":[15,0,4,0,4,133,3],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#af04c83d3598f1d70089dbd305c16752c":[14,0,6,0,5,134,1],
+"classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#af04c83d3598f1d70089dbd305c16752c":[15,0,4,0,4,133,1],
 "classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#af08413a3ee12cf78b0ddeea71e2648b3":[14,0,6,0,5,134,28],
 "classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#af08413a3ee12cf78b0ddeea71e2648b3":[15,0,4,0,4,133,28],
 "classopenvdb_1_1v12__0_1_1math_1_1NineteenPointStencil.html#af2d5d92dfd52e23c51ffaa35cf4dba4d":[14,0,6,0,5,134,2],
@@ -223,31 +249,5 @@ var NAVTREEINDEX32 =
 "classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ac4a1050be02b20b3f791b9a483f3abe2":[14,0,6,0,5,139,55],
 "classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ac4a1050be02b20b3f791b9a483f3abe2":[15,0,4,0,4,138,55],
 "classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ac63b5f9ff57c7f97ab44b79f59746c71":[14,0,6,0,5,139,15],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ac63b5f9ff57c7f97ab44b79f59746c71":[15,0,4,0,4,138,15],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ac9ca720e14833f50c05bee6f3de9185c":[14,0,6,0,5,139,23],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ac9ca720e14833f50c05bee6f3de9185c":[15,0,4,0,4,138,23],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#acc3b773e5965248fb65922197958e3a9":[14,0,6,0,5,139,39],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#acc3b773e5965248fb65922197958e3a9":[15,0,4,0,4,138,39],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ad0561ec473355048d1b49e9dc900193a":[14,0,6,0,5,139,22],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ad0561ec473355048d1b49e9dc900193a":[15,0,4,0,4,138,22],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ad1141e7b8d70721e8bbbcc8cd221d293":[14,0,6,0,5,139,12],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ad1141e7b8d70721e8bbbcc8cd221d293":[15,0,4,0,4,138,12],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ade560cba6b10bb7117afaccbf07c4fc5":[14,0,6,0,5,139,38],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ade560cba6b10bb7117afaccbf07c4fc5":[15,0,4,0,4,138,38],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#adec4d6e4697fff19761dfb957ab203f2":[14,0,6,0,5,139,24],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#adec4d6e4697fff19761dfb957ab203f2":[15,0,4,0,4,138,24],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ae1e206b98c0ad034bf0ae89b89d623c1":[14,0,6,0,5,139,28],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ae1e206b98c0ad034bf0ae89b89d623c1":[15,0,4,0,4,138,28],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ae88aad6ab980ed9ef001bbab4c1cbfbd":[14,0,6,0,5,139,61],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ae88aad6ab980ed9ef001bbab4c1cbfbd":[15,0,4,0,4,138,61],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ae9b08fca99a89639cd78a91152a64d5f":[14,0,6,0,5,139,46],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ae9b08fca99a89639cd78a91152a64d5f":[15,0,4,0,4,138,46],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#aea60bacac9490ebd9edc4efd1d2f294c":[14,0,6,0,5,139,60],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#aea60bacac9490ebd9edc4efd1d2f294c":[15,0,4,0,4,138,60],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#aeac1fbe9cbd74a976f0f3bd4768cd202":[14,0,6,0,5,139,35],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#aeac1fbe9cbd74a976f0f3bd4768cd202":[15,0,4,0,4,138,35],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#aecaeabaa9da616ae42bb20787878260d":[14,0,6,0,5,139,1],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#aecaeabaa9da616ae42bb20787878260d":[15,0,4,0,4,138,1],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#aeefe128375e3fecc343fa076bb3b22ce":[14,0,6,0,5,139,20],
-"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#aeefe128375e3fecc343fa076bb3b22ce":[15,0,4,0,4,138,20]
+"classopenvdb_1_1v12__0_1_1math_1_1Quat.html#ac63b5f9ff57c7f97ab44b79f59746c71":[15,0,4,0,4,138,15]
 };
